@@ -8,10 +8,7 @@ class Embed:
         self.title = None if title is None else title
         self.description = None if description is None else description
         self.color = 0x2f3136 if color is None else color
-        self.fields = []
-        self.footer = {}
-        self.author = {}
-        self.author = {}
+        self.__built = {"type": "rich", "title": self.title, "description": self.description, "color": self.color}
 
     def add_field(self, name: str = None, value: str = None, inline: bool = False) -> E:
         """Adds a field object to the Embed"""
@@ -22,32 +19,64 @@ class Embed:
         if name is None and value is None:
             raise ValueError("Embed.field object cannot be empty.")
 
-        self.fields.append({"name": name, "value": value, "inline": inline})
+        try:
+            self.__built['fields'].append({"name": name, "value": value, "inline": inline})
+        except KeyError:
+            self.__built['fields'] = [{"name": name, "value": value, "inline": inline}]
 
         return self
 
     def set_footer(self, text: str = None, icon_url: str = None) -> E:
         if text is None and icon_url is None:
             raise ValueError("Embed.footer object cannot be empty.")
-        self.footer['text'] = text
-        if icon_url is not None:
-            self.footer['icon_url'] = icon_url
+
+        try:
+            self.__built['footer']['text'] = text
+            if icon_url is not None:
+                self.__built['footer']['icon_url'] = icon_url
+        except KeyError:
+            self.__built['footer'] = {"text": text}
+            if icon_url is not None:
+                self.__built['footer']['icon_url'] = icon_url
+
+        #self.footer['text'] = text
+        #if icon_url is not None:
+            #self.footer['icon_url'] = icon_url
 
         return self
 
     def set_author(self, name: str = None, url: str = None, icon_url: str = None) -> E:
         if name is None and url is None and icon_url is None:
             raise ValueError("Embed.author object cannot be empty.")
-        
-        if name is not None:
-            self.author['name'] = name
-        if url is not None:
-            self.author['url'] = url
-        if icon_url is not None:
-            self.author['icon_url'] = icon_url
+
+        try:
+            if name is not None:
+                self.__built['author']['name'] = name
+            if url is not None:
+                self.__built['author']['url'] = url
+            if icon_url is not None:
+                self.__built['author']['icon_url'] = icon_url
+        except KeyError:
+            self.__built['author'] = {}
+            if name is not None:
+                self.__built['author']['name'] = name
+            if url is not None:
+                self.__built['author']['url'] = url
+            if icon_url is not None:
+                self.__built['author']['icon_url'] = icon_url
 
         return self
 
+    def set_image(self, image_url: str):
+        self.__built['image'] = {}
+        self.__built['image']['url'] = image_url
+
+        return self
+
+    def set_thumbnail(self, thumbnail_url: str):
+        self.__built['thumbnail'] = {}
+        self.__built['thumbnail']['url'] = thumbnail_url
+
     def build(self) -> dict:
         built = {}
         if self.title is not None:
@@ -64,4 +93,4 @@ class Embed:
         if len(self.author.keys()) > 0:
             built['author'] = self.author
 
-        return built
\ No newline at end of file
+        return self.__built
\ No newline at end of file
